@@ -253,14 +253,14 @@ def sync_current_dir():
         })
     except Exception as e:
         msg_obj = {
-            'trial' : 'upload features are only enabled for subscribed shell2 users. upgrade your account for the full shell2 experience !'
+            'upload_limits' : 'unable to upload. if you are a trial user, uploads storage is limited.'
         }
         console.print( f'[red]{json.dumps(  msg_obj , indent=1 )}[/red]' )
         os.remove(FOLDER_STATE_7Z)
         return
     if not response['status']:
         msg_obj = {
-            'trial' : 'upload features are only enabled for subscribed shell2 users. upgrade your account for the full shell2 experience !'
+            'upload_limits' : 'unable to upload. if you are a trial user, uploads storage is limited.'
         }    
         console.print( f'[red]{json.dumps(  msg_obj , indent=1 )}[/red]' )
         os.remove(FOLDER_STATE_7Z)
@@ -739,7 +739,7 @@ def session_join(sessionId,user):
     
     sdkStreamData = _postWithRetry(
         'https://api.shell2.raiden.ai/user/sdk/stream' ,
-        {'sessionId' : SESSION_ID},
+        {'sessionId' : SESSION_ID , 'user' : SESSION_USER },
         {'key':API_KEY}
     )
     
@@ -752,6 +752,8 @@ def session_join(sessionId,user):
     sdkStreamData['messages'] = f'userdata/{SESSION_USER}/automation_layer/shell2/session/{SESSION_ID}/message'
     
     
+    # print(sdkStreamData)
+    
     firestoreClient = firestore.Client(
         project = sdkStreamData['config']['projectId'],
         credentials = Credentials(sdkStreamData['token']['idToken'], sdkStreamData['token']['refreshToken']),
